==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/ca.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Tema de contrast alt",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un tema de contrast alt per facilitar la navegació. La qualitat visual es reduirà però s'incrementarà la claredat.",
    "Dark theme (beta)" : "Tema fosc (beta)",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Un tema fosc per ajudar els ulls reduint la lluminositat i la brillantor totals. És sota desenvolupament, de manera que si us plau informeu de les errades que hi pugueu trobar. ",
    "Dyslexia font" : "Tipus de lletra per a la dislèxia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic és un tipus de lletra gratuït dissenyat per mitigar alguns dels errors de lectura habituals causats per la dislèxia.",
    "Accessibility" : "Accessibilitat",
    "Accessibility options for nextcloud" : "Paràmetres d'accessibilitat de Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Proporciona diversos paràmetres d'accessibilitat per facilitar-vos l'ús de Nextcloud",
    "Web Content Accessibility Guidelines" : "Pautes d'accessibilitat de continguts web",
    "our issue tracker" : "el nostre seguidor d'incidències",
    "our design team" : "el nostre equip de disseny",
    "Enable" : "Activa"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/ca.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Tema de contrast alt",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un tema de contrast alt per facilitar la navegació. La qualitat visual es reduirà però s'incrementarà la claredat.",
    "Dark theme" : "Tema fosc",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Un tema fosc per ajudar els ulls reduint la lluminositat i la brillantor totals. És sota desenvolupament, de manera que si us plau informeu de les errades que hi pugueu trobar. ",
    "Dyslexia font" : "Tipus de lletra per a la dislèxia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic és un tipus de lletra gratuït dissenyat per mitigar alguns dels errors de lectura habituals causats per la dislèxia.",
    "Accessibility" : "Accessibilitat",
    "Accessibility options for nextcloud" : "Paràmetres d'accessibilitat de Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Proporciona diversos paràmetres d'accessibilitat per facilitar-vos l'ús de Nextcloud",
    "Web Content Accessibility Guidelines" : "Pautes d'accessibilitat de continguts web",
    "our issue tracker" : "el nostre seguidor d'incidències",
    "our design team" : "el nostre equip de disseny",
    "Enable" : "Activa",
    "Dark theme (beta)" : "Tema fosc (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic és una tipografia gratuïta dissenyada per reduir alguns dels problemes comuns de lectura causats per la dislèxia. La tipografia fou creada per Abelardo González, que la va publicar amb una llicència oberta.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Proporciona múltiples opcions d'accessibilitat per facilitar l'ús de Nextcloud",
    "Themes" : "Temes",
    "Fonts" : "Tipografies",
    "enabled" : "activat"
},
"nplurals=2; plural=(n != 1);");
